@@ -5,11 +5,13 @@ import uuid
 import asyncssh
 import jinja2
 
+from .base import MixinBase
+
 
 ENVIRONMENT = jinja2.Environment(enable_async=True)
 
 
-class TemplateMixin:
+class TemplateMixin(MixinBase):
     async def upload_template(
         self,
         local_path: str,
@@ -36,7 +38,7 @@ class TemplateMixin:
         with open(tmp_file_path, "w") as f:
             f.write(contents)
 
-        connection = await self.host.get_connection()
+        connection = await self.host_class.get_connection()
 
         self._print_command(f"Uploading: {local_path} -> {remote_path}\n")
 
