@@ -22,16 +22,17 @@ class DockerHost(Host):
 
     username = "root"
     address = "localhost"
-    connection_params = {"password": "root"}
+    connection_params = {"password": "root", "known_hosts": None}
 
 
 @task_registry.register
 class TaskOne(Task):
     async def run(self):
         await self.apt_update()
+        await self.apt_install("apt-utils")
         await self.apt_install("rolldice")
         global RESPONSE
-        RESPONSE = (await self.raw("cat /etc/os-release")).stdout
+        RESPONSE = (await self.raw("/usr/games/rolldice -v")).stdout
 
 
 class TestConnection:
@@ -48,4 +49,4 @@ class TestConnection:
 
     def test_apt_install(self):
         asyncio.run(self.run_tasks())
-        assert "Ubuntu" in RESPONSE
+        assert "rolldice" in RESPONSE
